==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/it.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
    "Storage invalid" : "Archiviazione non valida",
    "Unknown error" : "Errore sconosciuto",
    "All files" : "Tutti i file",
    "Recent" : "Recenti",
    "Favorites" : "Preferiti",
    "File could not be found" : "Il file non può essere trovato",
    "Move or copy" : "Sposta o copia",
    "Download" : "Scarica",
    "Delete" : "Elimina",
    "Home" : "Home",
    "Close" : "Chiudi",
    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
    "This will stop your current uploads." : "Questo fermerà i caricamenti attuali.",
    "Upload cancelled." : "Caricamento annullato.",
    "…" : "…",
    "Processing files …" : "Elaborazione file in corso…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La cartella di destinazione \"{dir}\" non esiste più",
    "Not enough free space" : "Spazio libero insufficiente",
    "An unknown error has occurred" : "Si è verificato un errore sconosciuto",
    "Uploading …" : "Caricamento in corso...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Il caricamento di tale elemento non è supportato",
    "Target folder does not exist any more" : "La cartella di destinazione non esiste più",
    "Error when assembling chunks, status code {status}" : "Errore durante l'assemblaggio dei blocchi, codice di stato {status}",
    "Actions" : "Azioni",
    "Rename" : "Rinomina",
    "Copy" : "Copia",
    "Choose target folder" : "Scegli la cartella di destinazione",
    "Disconnect storage" : "Disconnetti archiviazione",
    "Unshare" : "Rimuovi condivisione",
    "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
    "Files" : "File",
    "Details" : "Dettagli",
    "Select" : "Seleziona",
    "Pending" : "In corso",
    "Unable to determine date" : "Impossibile determinare la data",
    "This operation is forbidden" : "Questa operazione è vietata",
    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
    "copy" : "copia",
    "Could not copy \"{file}\", target exists" : "Impossibile copiare \"{file}\", la destinazione esiste già",
    "Could not copy \"{file}\"" : "Impossibile copiare \"{file}\"",
    "Copied {origin} inside {destination}" : "Copiato {origin} in {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiati {origin} e {nbfiles} altri file in {destination}",
    "{newName} already exists" : "{newName} esiste già",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossibile rinominare \"{fileName}\", non esiste più",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{targetName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
    "Could not rename \"{fileName}\"" : "Impossibile rinominare \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
    "Could not create folder \"{dir}\" because it already exists" : "Impossibile creare la cartella \"{dir}\" poiché esiste già",
    "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nessun risultato di ricerca nelle altre cartelle per {tag}{filter}{endtag}",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle"],
    "_%n file_::_%n files_" : ["%n file","%n file"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluso %n nascosto","inclusi %n nascosti"],
    "You don’t have permission to upload or create files here" : "Qui non hai i permessi per caricare o creare file",
    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso"],
    "New" : "Nuovo",
    "Select file range" : "Seleziona intervallo di file",
    "{used} of {quota} used" : "{used} di {quota} utilizzati",
    "{used} used" : "{used} utilizzati",
    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "\"/\" is not allowed inside a file name." : "\"/\" non è consentito nel nome di un file.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" non è un tipo di file valido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione di {owner} è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["corrispondono a '{filter}'","corrisponde a '{filter}'"],
    "View in folder" : "Visualizza nella cartella",
    "Copied!" : "Copiato!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
    "Path" : "Percorso",
    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
    "Favorited" : "Preferiti",
    "Favorite" : "Preferito",
    "You can only favorite a single file or folder at a time" : "Puoi aggiungere ai preferiti un singolo file o cartella alla volta",
    "New folder" : "Nuova cartella",
    "Upload file" : "Carica file",
    "Not favorited" : "Non preferito",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add to favorites" : "Aggiungi ai preferiti",
    "An error occurred while trying to update the tags" : "Si è verificato un errore durante il tentativo di aggiornare le etichette",
    "Added to favorites" : "Aggiunto ai preferiti",
    "Removed from favorites" : "Rimosso dai preferiti",
    "You added {file} to your favorites" : "Hai aggiunto {file} ai tuoi preferiti",
    "You removed {file} from your favorites" : "Hai rimosso {file} dai tuoi preferiti",
    "File changes" : "Modifiche dei file",
    "Created by {user}" : "Creata da {user}",
    "Changed by {user}" : "Modificata da {user}",
    "Deleted by {user}" : "Eliminata da {user}",
    "Restored by {user}" : "Ripristinata da {user}",
    "Renamed by {user}" : "Rinominata da {user}",
    "Moved by {user}" : "Spostata da {user}",
    "\"remote user\"" : "\"utente remoto\"",
    "You created {file}" : "Hai creato {file}",
    "You created an encrypted file in {file}" : "Hai creato un file cifrato in {file}",
    "{user} created {file}" : "{user} ha creato {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creato un file cifrato in {file}",
    "{file} was created in a public folder" : "{file} è stato creato in una cartella pubblica",
    "You changed {file}" : "Hai modificato {file}",
    "You changed an encrypted file in {file}" : "Hai cambiato un file cifrato in {file}",
    "{user} changed {file}" : "{user} ha modificato {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha cambiato un file cifrato in {file}",
    "You deleted {file}" : "Hai eliminato {file}",
    "You deleted an encrypted file in {file}" : "Hai eliminato un file cifrato in {file}",
    "{user} deleted {file}" : "{user} ha eliminato {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha eliminato un file cifrato in {file}",
    "You restored {file}" : "Hai ripristinato {file}",
    "{user} restored {file}" : "{user1} ha ripristinato {file}",
    "You renamed {oldfile} to {newfile}" : "Hai rinominato {oldfile} in {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha rinominato {oldfile} in {newfile}",
    "You moved {oldfile} to {newfile}" : "Hai spostato {oldfile} in {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} ha spostato {oldfile} in {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un file  stato aggiunto o rimosso dai tuoi <strong>preferiti</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un file o una cartella è stato <strong>modificato</strong> o <strong>rinominato</strong>",
    "A new file or folder has been <strong>created</strong>" : "Un nuovo file o cartella è stato <strong>creato</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un file o una cartella è stato <strong>eliminato</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita le notifiche relative alla creazione e alla modifica dei tuoi <strong>file preferiti</strong> <em>(Solo flusso)</em>",
    "A file or folder has been <strong>restored</strong>" : "Un file o una cartella è stato <strong>ripristinato</strong>",
    "Unlimited" : "Illimitata",
    "Upload (max. %s)" : "Carica (massimo %s)",
    "File Management" : "Gestione dei file",
    "File handling" : "Gestione file",
    "Maximum upload size" : "Dimensione massima caricamento",
    "max. possible: " : "numero mass.: ",
    "Save" : "Salva",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM potrebbe richiedere 5 minuti perché le modifiche siano applicate.",
    "Missing permissions to edit from here." : "Permessi mancanti per modificare da qui.",
    "%s of %s used" : "%s di %s utilizzati",
    "%1$s%% of %2$s used" : "%1$s%% di %2$s utilizzati",
    "%s used" : "%s utilizzato",
    "Settings" : "Impostazioni",
    "Show hidden files" : "Mostra i file nascosti",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Utilizza questo indirizzo per <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">accedere ai tuoi file con WebDAV</a>",
    "Toggle grid view" : "Commuta la vista a griglia",
    "Cancel upload" : "Annulla caricamento",
    "No files in here" : "Qui non c'è alcun file",
    "Upload some content or sync with your devices!" : "Carica alcuni contenuti o sincronizza con i tuoi dispositivi!",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Select all" : "Seleziona tutto",
    "Upload too large" : "Caricamento troppo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "I file che stai provando a caricare superano la dimensione massima consentita su questo server.",
    "No favorites yet" : "Nessun preferito ancora",
    "Files and folders you mark as favorite will show up here" : "I file e le cartelle che marchi come preferiti saranno mostrati qui",
    "Tags" : "Etichette",
    "Deleted files" : "File eliminati",
    "Shares" : "Condivisioni",
    "Shared with others" : "Condivisi con altri",
    "Shared with you" : "Condivisi con te",
    "Shared by link" : "Condivisi tramite collegamento",
    "Deleted shares" : "Condivisioni eliminate",
    "Text file" : "File di testo",
    "New text file.txt" : "Nuovo file di testo.txt",
    "Target folder" : "Cartella di destinazione",
    "%1$s of %2$s used" : "%1$s di %2$s utilizzati"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/it.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
    "Storage invalid" : "Archiviazione non valida",
    "Unknown error" : "Errore sconosciuto",
    "All files" : "Tutti i file",
    "Recent" : "Recenti",
    "Favorites" : "Preferiti",
    "File could not be found" : "Il file non può essere trovato",
    "Move or copy" : "Sposta o copia",
    "Download" : "Scarica",
    "Delete" : "Elimina",
    "Home" : "Home",
    "Close" : "Chiudi",
    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
    "This will stop your current uploads." : "Questo fermerà i caricamenti attuali.",
    "Upload cancelled." : "Caricamento annullato.",
    "Processing files …" : "Elaborazione file in corso…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La cartella di destinazione \"{dir}\" non esiste più",
    "Not enough free space" : "Spazio libero insufficiente",
    "An unknown error has occurred" : "Si è verificato un errore sconosciuto",
    "Uploading …" : "Caricamento in corso...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Il caricamento di tale elemento non è supportato",
    "Target folder does not exist any more" : "La cartella di destinazione non esiste più",
    "Error when assembling chunks, status code {status}" : "Errore durante l'assemblaggio dei blocchi, codice di stato {status}",
    "Actions" : "Azioni",
    "Rename" : "Rinomina",
    "Copy" : "Copia",
    "Choose target folder" : "Scegli la cartella di destinazione",
    "Open" : "Apri",
    "Delete file" : "Elimina file",
    "Delete folder" : "Elimina cartella",
    "Disconnect storage" : "Disconnetti archiviazione",
    "Unshare" : "Rimuovi condivisione",
    "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
    "Files" : "File",
    "Details" : "Dettagli",
    "Select" : "Seleziona",
    "Pending" : "In corso",
    "Unable to determine date" : "Impossibile determinare la data",
    "This operation is forbidden" : "Questa operazione è vietata",
    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
    "copy" : "copia",
    "Could not copy \"{file}\", target exists" : "Impossibile copiare \"{file}\", la destinazione esiste già",
    "Could not copy \"{file}\"" : "Impossibile copiare \"{file}\"",
    "Copied {origin} inside {destination}" : "Copiato {origin} in {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiati {origin} e {nbfiles} altri file in {destination}",
    "{newName} already exists" : "{newName} esiste già",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossibile rinominare \"{fileName}\", non esiste più",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{targetName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
    "Could not rename \"{fileName}\"" : "Impossibile rinominare \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
    "Could not create folder \"{dir}\" because it already exists" : "Impossibile creare la cartella \"{dir}\" poiché esiste già",
    "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nessun risultato di ricerca nelle altre cartelle per {tag}{filter}{endtag}",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle"],
    "_%n file_::_%n files_" : ["%n file","%n file"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluso %n nascosto","inclusi %n nascosti"],
    "You don’t have permission to upload or create files here" : "Qui non hai i permessi per caricare o creare file",
    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso"],
    "New" : "Nuovo",
    "Select file range" : "Seleziona intervallo di file",
    "{used} of {quota} used" : "{used} di {quota} utilizzati",
    "{used} used" : "{used} utilizzati",
    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "\"/\" is not allowed inside a file name." : "\"/\" non è consentito nel nome di un file.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" non è un tipo di file valido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione di {owner} è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["corrispondono a '{filter}'","corrisponde a '{filter}'"],
    "View in folder" : "Visualizza nella cartella",
    "Copied!" : "Copiato!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
    "Path" : "Percorso",
    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
    "Favorited" : "Preferiti",
    "Favorite" : "Preferito",
    "You can only favorite a single file or folder at a time" : "Puoi aggiungere ai preferiti un singolo file o cartella alla volta",
    "New folder" : "Nuova cartella",
    "Upload file" : "Carica file",
    "Not favorited" : "Non preferito",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add to favorites" : "Aggiungi ai preferiti",
    "An error occurred while trying to update the tags" : "Si è verificato un errore durante il tentativo di aggiornare le etichette",
    "Added to favorites" : "Aggiunto ai preferiti",
    "Removed from favorites" : "Rimosso dai preferiti",
    "You added {file} to your favorites" : "Hai aggiunto {file} ai tuoi preferiti",
    "You removed {file} from your favorites" : "Hai rimosso {file} dai tuoi preferiti",
    "File changes" : "Modifiche dei file",
    "Created by {user}" : "Creata da {user}",
    "Changed by {user}" : "Modificata da {user}",
    "Deleted by {user}" : "Eliminata da {user}",
    "Restored by {user}" : "Ripristinata da {user}",
    "Renamed by {user}" : "Rinominata da {user}",
    "Moved by {user}" : "Spostata da {user}",
    "\"remote user\"" : "\"utente remoto\"",
    "You created {file}" : "Hai creato {file}",
    "You created an encrypted file in {file}" : "Hai creato un file cifrato in {file}",
    "{user} created {file}" : "{user} ha creato {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creato un file cifrato in {file}",
    "{file} was created in a public folder" : "{file} è stato creato in una cartella pubblica",
    "You changed {file}" : "Hai modificato {file}",
    "You changed an encrypted file in {file}" : "Hai cambiato un file cifrato in {file}",
    "{user} changed {file}" : "{user} ha modificato {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha cambiato un file cifrato in {file}",
    "You deleted {file}" : "Hai eliminato {file}",
    "You deleted an encrypted file in {file}" : "Hai eliminato un file cifrato in {file}",
    "{user} deleted {file}" : "{user} ha eliminato {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha eliminato un file cifrato in {file}",
    "You restored {file}" : "Hai ripristinato {file}",
    "{user} restored {file}" : "{user1} ha ripristinato {file}",
    "You renamed {oldfile} to {newfile}" : "Hai rinominato {oldfile} in {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha rinominato {oldfile} in {newfile}",
    "You moved {oldfile} to {newfile}" : "Hai spostato {oldfile} in {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} ha spostato {oldfile} in {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un file  stato aggiunto o rimosso dai tuoi <strong>preferiti</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un file o una cartella è stato <strong>modificato</strong> o <strong>rinominato</strong>",
    "A new file or folder has been <strong>created</strong>" : "Un nuovo file o cartella è stato <strong>creato</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un file o una cartella è stato <strong>eliminato</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita le notifiche relative alla creazione e alla modifica dei tuoi <strong>file preferiti</strong> <em>(Solo flusso)</em>",
    "A file or folder has been <strong>restored</strong>" : "Un file o una cartella è stato <strong>ripristinato</strong>",
    "Unlimited" : "Illimitata",
    "Upload (max. %s)" : "Carica (massimo %s)",
    "File Management" : "Gestione dei file",
    "Error while loading the file data" : "Errore durante il caricamento del file di dati",
    "Unable to change the favourite state of the file" : "Impossibile cambiare lo stato di preferito del file",
    "%s used" : "%s utilizzato",
    "%s%% of %s used" : "%s%% di %s utilizzati",
    "%1$s of %2$s used" : "%1$s di %2$s utilizzati",
    "Settings" : "Impostazioni",
    "Show hidden files" : "Mostra i file nascosti",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Utilizza questo indirizzo per <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">accedere ai tuoi file con WebDAV</a>",
    "Toggle grid view" : "Commuta la vista a griglia",
    "No files in here" : "Qui non c'è alcun file",
    "Upload some content or sync with your devices!" : "Carica alcuni contenuti o sincronizza con i tuoi dispositivi!",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Select all" : "Seleziona tutto",
    "Upload too large" : "Caricamento troppo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "I file che stai provando a caricare superano la dimensione massima consentita su questo server.",
    "No favorites yet" : "Nessun preferito ancora",
    "Files and folders you mark as favorite will show up here" : "I file e le cartelle che marchi come preferiti saranno mostrati qui",
    "Tags" : "Etichette",
    "Deleted files" : "File eliminati",
    "Shares" : "Condivisioni",
    "Shared with others" : "Condivisi con altri",
    "Shared with you" : "Condivisi con te",
    "Shared by link" : "Condivisi tramite collegamento",
    "Deleted shares" : "Condivisioni eliminate",
    "Text file" : "File di testo",
    "New text file.txt" : "Nuovo file di testo.txt",
    "File handling" : "Gestione file",
    "Maximum upload size" : "Dimensione massima caricamento",
    "max. possible: " : "numero mass.: ",
    "Save" : "Salva",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM potrebbe richiedere 5 minuti perché le modifiche siano applicate.",
    "Missing permissions to edit from here." : "Permessi mancanti per modificare da qui.",
    "Cancel upload" : "Annulla caricamento",
    "%s of %s used" : "%s di %s utilizzati",
    "%1$s%% of %2$s used" : "%1$s%% di %2$s utilizzati"
},
"nplurals=2; plural=(n != 1);");
